kenchi package
==============

Subpackages
-----------

.. toctree::

    kenchi.outlier_detection

Submodules
----------

.. toctree::

   kenchi.datasets
   kenchi.pipeline
   kenchi.utils
   kenchi.visualization

Module contents
---------------

.. automodule:: kenchi
    :members:
    :undoc-members:
    :show-inheritance:
